Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2379)

Unified Diff: net/tools/epoll_server/epoll_server.h

Issue 82913011: LOG(INFO) tidying in net/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: revert dns_fuzz_stub changes Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/tools/dump_cache/simple_cache_dumper.cc ('k') | net/tools/epoll_server/epoll_server.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/tools/epoll_server/epoll_server.h
diff --git a/net/tools/epoll_server/epoll_server.h b/net/tools/epoll_server/epoll_server.h
index 8822450860073b0cad866c5d66858601d26ecdfc..d167a97ac42e3b470b083792bb5e74d7df08005b 100644
--- a/net/tools/epoll_server/epoll_server.h
+++ b/net/tools/epoll_server/epoll_server.h
@@ -720,10 +720,10 @@ class EpollServer {
// When a number of events equals the record threshold,
// the collected data summary for all FDs will be written
// to LOG(INFO). Note that this does not include the
// individual events (if you'reinterested in those, you'll
// have to get at them programmatically).
// After any such flushing to LOG(INFO) all events will
// be cleared.
// Note that the definition of an 'event' is a bit 'hazy',
// as it includes the 'Unregistration' event, and perhaps
@@ -745,7 +745,7 @@ class EpollServer {
++num_records_;
if ((num_records_ > record_threshold_) &&
(record_threshold_ > 0)) {
- LOG(INFO) << "\n" << *this;
+ VLOG(0) << "\n" << *this;
num_records_ = 0;
Clear();
}
@@ -720,10 +720,10 @@ class EpollServer {
// When a number of events equals the record threshold,
// the collected data summary for all FDs will be written
- // to LOG(INFO). Note that this does not include the
+ // to VLOG(0). Note that this does not include the
// individual events (if you'reinterested in those, you'll
// have to get at them programmatically).
@@ -720,10 +720,10 @@ class EpollServer {
// individual events (if you'reinterested in those, you'll
// have to get at them programmatically).
- // After any such flushing to LOG(INFO) all events will
+ // After any such flushing to VLOG(0) all events will
// be cleared.
// Note that the definition of an 'event' is a bit 'hazy',
« no previous file with comments | « net/tools/dump_cache/simple_cache_dumper.cc ('k') | net/tools/epoll_server/epoll_server.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698